@@ -11,8 +11,9 @@ class TestStore(unittest.TestCase):
     @classmethod
     def setUpClass(self):
         __init__.get_coins()
-        for i in range(40):
+        for i in range(120):
             gevent.sleep(1)
+            print i
         
     def testCoins(self):
         for item in __init__.get_coins():
@@ -73,5 +74,13 @@ class TestStore(unittest.TestCase):
         print pool.blocks
         assert pool.blocks != None
         assert len(json.loads(pool.blocks))
+
+    def testSetInfo(self):
+        __init__.get_pool('deepbit').namespace.get_node('shares').set_value(0)
+        assert __init__.get_pool('deepbit').shares == 0
+
+
+    def testprintSlushShares(self):
+        print __init__.get_pool('slush').shares
 if __name__ == "__main__":
     unittest.main()  
